# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ...types.v2 import crawl_list_params, crawl_crawl_params
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...pagination import SyncCrawlPagination, AsyncCrawlPagination
from ..._base_client import AsyncPaginator, make_request_options
from ...types.v2.crawl_get_response import CrawlGetResponse
from ...types.v2.crawl_list_response import CrawlListResponse
from ...types.v2.crawl_crawl_response import CrawlCrawlResponse
from ...types.v2.crawl_cancel_response import CrawlCancelResponse

__all__ = ["CrawlResource", "AsyncCrawlResource"]


class CrawlResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> CrawlResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Nimbleway/webit-client-python#accessing-raw-response-data-eg-headers
        """
        return CrawlResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CrawlResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Nimbleway/webit-client-python#with_streaming_response
        """
        return CrawlResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        status: Literal["queued", "running", "succeeded", "failed", "canceled"],
        cursor: Optional[str] | Omit = omit,
        limit: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncCrawlPagination[CrawlListResponse]:
        """
        Crawl by Filter

        Args:
          status: Filter crawls by their status.

          cursor: Cursor for pagination.

          limit: Number of crawls to return per page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/crawl",
            page=SyncCrawlPagination[CrawlListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "status": status,
                        "cursor": cursor,
                        "limit": limit,
                    },
                    crawl_list_params.CrawlListParams,
                ),
            ),
            model=CrawlListResponse,
        )

    def cancel(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CrawlCancelResponse:
        """
        Cancel Crawl

        Args:
          id: The unique identifier of the crawl task.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._delete(
            f"/crawl/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CrawlCancelResponse,
        )

    def crawl(
        self,
        *,
        url: str,
        allow_external_links: bool | Omit = omit,
        allow_subdomains: bool | Omit = omit,
        callback: crawl_crawl_params.Callback | Omit = omit,
        crawl_entire_domain: bool | Omit = omit,
        exclude_paths: SequenceNotStr[str] | Omit = omit,
        extract_options: crawl_crawl_params.ExtractOptions | Omit = omit,
        ignore_query_parameters: bool | Omit = omit,
        include_paths: SequenceNotStr[str] | Omit = omit,
        limit: int | Omit = omit,
        max_discovery_depth: int | Omit = omit,
        name: str | Omit = omit,
        sitemap: Literal["skip", "include", "only"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CrawlCrawlResponse:
        """
        Create crawl task

        Args:
          url: Url to crawl.

          allow_external_links: Allows the crawler to follow links to external websites.

          allow_subdomains: Allows the crawler to follow links to subdomains of the main domain.

          callback: Webhook configuration for receiving crawl results.

          crawl_entire_domain: Allows the crawler to follow internal links to sibling or parent URLs, not just
              child paths.

          exclude_paths: URL pathname regex patterns that exclude matching URLs from the crawl.

          ignore_query_parameters: Do not re-scrape the same path with different (or none) query parameters.

          include_paths: URL pathname regex patterns that include matching URLs in the crawl.

          limit: Maximum number of pages to crawl.

          max_discovery_depth: Maximum depth to crawl based on discovery order.

          name: Name of the crawl.

          sitemap: Sitemap and other methods will be used together to find URLs.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/crawl",
            body=maybe_transform(
                {
                    "url": url,
                    "allow_external_links": allow_external_links,
                    "allow_subdomains": allow_subdomains,
                    "callback": callback,
                    "crawl_entire_domain": crawl_entire_domain,
                    "exclude_paths": exclude_paths,
                    "extract_options": extract_options,
                    "ignore_query_parameters": ignore_query_parameters,
                    "include_paths": include_paths,
                    "limit": limit,
                    "max_discovery_depth": max_discovery_depth,
                    "name": name,
                    "sitemap": sitemap,
                },
                crawl_crawl_params.CrawlCrawlParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CrawlCrawlResponse,
        )

    def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CrawlGetResponse:
        """
        Get crawl data

        Args:
          id: The unique identifier of the crawl task.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/crawl/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CrawlGetResponse,
        )


class AsyncCrawlResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncCrawlResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Nimbleway/webit-client-python#accessing-raw-response-data-eg-headers
        """
        return AsyncCrawlResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCrawlResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Nimbleway/webit-client-python#with_streaming_response
        """
        return AsyncCrawlResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        status: Literal["queued", "running", "succeeded", "failed", "canceled"],
        cursor: Optional[str] | Omit = omit,
        limit: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[CrawlListResponse, AsyncCrawlPagination[CrawlListResponse]]:
        """
        Crawl by Filter

        Args:
          status: Filter crawls by their status.

          cursor: Cursor for pagination.

          limit: Number of crawls to return per page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/crawl",
            page=AsyncCrawlPagination[CrawlListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "status": status,
                        "cursor": cursor,
                        "limit": limit,
                    },
                    crawl_list_params.CrawlListParams,
                ),
            ),
            model=CrawlListResponse,
        )

    async def cancel(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CrawlCancelResponse:
        """
        Cancel Crawl

        Args:
          id: The unique identifier of the crawl task.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._delete(
            f"/crawl/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CrawlCancelResponse,
        )

    async def crawl(
        self,
        *,
        url: str,
        allow_external_links: bool | Omit = omit,
        allow_subdomains: bool | Omit = omit,
        callback: crawl_crawl_params.Callback | Omit = omit,
        crawl_entire_domain: bool | Omit = omit,
        exclude_paths: SequenceNotStr[str] | Omit = omit,
        extract_options: crawl_crawl_params.ExtractOptions | Omit = omit,
        ignore_query_parameters: bool | Omit = omit,
        include_paths: SequenceNotStr[str] | Omit = omit,
        limit: int | Omit = omit,
        max_discovery_depth: int | Omit = omit,
        name: str | Omit = omit,
        sitemap: Literal["skip", "include", "only"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CrawlCrawlResponse:
        """
        Create crawl task

        Args:
          url: Url to crawl.

          allow_external_links: Allows the crawler to follow links to external websites.

          allow_subdomains: Allows the crawler to follow links to subdomains of the main domain.

          callback: Webhook configuration for receiving crawl results.

          crawl_entire_domain: Allows the crawler to follow internal links to sibling or parent URLs, not just
              child paths.

          exclude_paths: URL pathname regex patterns that exclude matching URLs from the crawl.

          ignore_query_parameters: Do not re-scrape the same path with different (or none) query parameters.

          include_paths: URL pathname regex patterns that include matching URLs in the crawl.

          limit: Maximum number of pages to crawl.

          max_discovery_depth: Maximum depth to crawl based on discovery order.

          name: Name of the crawl.

          sitemap: Sitemap and other methods will be used together to find URLs.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/crawl",
            body=await async_maybe_transform(
                {
                    "url": url,
                    "allow_external_links": allow_external_links,
                    "allow_subdomains": allow_subdomains,
                    "callback": callback,
                    "crawl_entire_domain": crawl_entire_domain,
                    "exclude_paths": exclude_paths,
                    "extract_options": extract_options,
                    "ignore_query_parameters": ignore_query_parameters,
                    "include_paths": include_paths,
                    "limit": limit,
                    "max_discovery_depth": max_discovery_depth,
                    "name": name,
                    "sitemap": sitemap,
                },
                crawl_crawl_params.CrawlCrawlParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CrawlCrawlResponse,
        )

    async def get(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CrawlGetResponse:
        """
        Get crawl data

        Args:
          id: The unique identifier of the crawl task.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/crawl/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CrawlGetResponse,
        )


class CrawlResourceWithRawResponse:
    def __init__(self, crawl: CrawlResource) -> None:
        self._crawl = crawl

        self.list = to_raw_response_wrapper(
            crawl.list,
        )
        self.cancel = to_raw_response_wrapper(
            crawl.cancel,
        )
        self.crawl = to_raw_response_wrapper(
            crawl.crawl,
        )
        self.get = to_raw_response_wrapper(
            crawl.get,
        )


class AsyncCrawlResourceWithRawResponse:
    def __init__(self, crawl: AsyncCrawlResource) -> None:
        self._crawl = crawl

        self.list = async_to_raw_response_wrapper(
            crawl.list,
        )
        self.cancel = async_to_raw_response_wrapper(
            crawl.cancel,
        )
        self.crawl = async_to_raw_response_wrapper(
            crawl.crawl,
        )
        self.get = async_to_raw_response_wrapper(
            crawl.get,
        )


class CrawlResourceWithStreamingResponse:
    def __init__(self, crawl: CrawlResource) -> None:
        self._crawl = crawl

        self.list = to_streamed_response_wrapper(
            crawl.list,
        )
        self.cancel = to_streamed_response_wrapper(
            crawl.cancel,
        )
        self.crawl = to_streamed_response_wrapper(
            crawl.crawl,
        )
        self.get = to_streamed_response_wrapper(
            crawl.get,
        )


class AsyncCrawlResourceWithStreamingResponse:
    def __init__(self, crawl: AsyncCrawlResource) -> None:
        self._crawl = crawl

        self.list = async_to_streamed_response_wrapper(
            crawl.list,
        )
        self.cancel = async_to_streamed_response_wrapper(
            crawl.cancel,
        )
        self.crawl = async_to_streamed_response_wrapper(
            crawl.crawl,
        )
        self.get = async_to_streamed_response_wrapper(
            crawl.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from nimbleway_webit import Nimbleway, AsyncNimbleway
from nimbleway_webit.types import V2MapResponse, V2ExtractResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV2:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_extract(self, client: Nimbleway) -> None:
        v2 = client.v2.extract(
            url="https://example.com/page",
        )
        assert_matches_type(V2ExtractResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_extract_with_all_params(self, client: Nimbleway) -> None:
        v2 = client.v2.extract(
            url="https://example.com/page",
            browser="chrome",
            city="Los Angeles",
            client_timeout=25000,
            consent_header=True,
            cookies=[
                {
                    "creation": "creation",
                    "domain": "domain",
                    "expires": "expires",
                    "extensions": ["string"],
                    "host_only": True,
                    "http_only": True,
                    "last_accessed": "lastAccessed",
                    "max_age": "Infinity",
                    "name": "name",
                    "path": "path",
                    "path_is_default": True,
                    "same_site": "strict",
                    "secure": True,
                    "value": "value",
                }
            ],
            country="US",
            device="desktop",
            disable_ip_check=False,
            driver="vx8",
            dynamic_parser={"myParser": "bar"},
            expected_status_codes=[200, 201],
            format="json",
            headers={
                "User-Agent": "CustomBot/1.0",
                "Accept-Language": "en-US",
            },
            http2=True,
            ip6=False,
            is_xhr=True,
            locale="en-US",
            markdown=False,
            metadata={
                "account_name": "acme-corp",
                "definition_id": 456,
                "definition_name": "product-scraper",
                "endpoint": "/api/v2/scrape",
                "execution_id": "exec-abc123",
                "flowit_task_id": "task-xyz789",
                "input_id": "input-123",
                "pipeline_execution_id": 12345,
                "query_template_id": "template-qry-001",
                "source": "web-app",
                "template_id": 789,
                "template_name": "e-commerce-template",
            },
            method="GET",
            native_mode="requester",
            network_capture=[
                {
                    "method": "GET",
                    "resource_type": "document",
                    "status_code": 100,
                    "url": {
                        "value": "value",
                        "type": "exact",
                    },
                    "validation": True,
                    "wait_for_requests_count": 0,
                    "wait_for_requests_count_timeout": 1,
                }
            ],
            no_html=False,
            no_userbrowser=False,
            os="windows",
            parse=True,
            parse_options={"merge_dynamic": True},
            parser={"myParser": "bar"},
            proxy_provider="brightdata",
            proxy_providers={
                "brightdata": 70,
                "oxylabs": 30,
            },
            query_template={
                "id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                "api_type": "WEB",
                "pagination": {"next_page_params": {"foo": "bar"}},
                "params": {"foo": "bar"},
            },
            raw_headers=True,
            referrer_type="random",
            render=True,
            render_flow=[{"wait": "bar"}, {"click": "bar"}],
            render_options={
                "adblock": True,
                "blocked_domains": ["ads.example.com", "tracker.com"],
                "browser_engine": "chrome",
                "cache": False,
                "connector_type": "puppeteer",
                "disabled_resources": ["image", "stylesheet"],
                "enable_2captcha": True,
                "extensions": ["extension-id-1", "extension-id-2"],
                "fingerprint_id": "fp-abc123",
                "hackium_configuration": {
                    "collect_logs": True,
                    "do_not_fix_math_salt": True,
                    "enable_document_element_spoof": True,
                    "enable_document_has_focus": True,
                    "enable_fake_navigation_history": True,
                    "enable_key_ordering": True,
                    "enable_sniffer": True,
                    "enable_verbose_logs": True,
                },
                "headless": True,
                "include_iframes": True,
                "load_local_storage": True,
                "local_storage_keys_to_load": ["authToken", "userId"],
                "mouse_strategy": "linear",
                "no_accept_encoding": True,
                "override_permissions": True,
                "random_header_order": True,
                "render_type": "domcontentloaded",
                "store_local_storage": True,
                "timeout": 30000,
                "typing_interval": 100,
                "typing_strategy": "simple",
                "userbrowser": True,
                "wait_until": "networkidle2",
                "with_performance_metrics": True,
            },
            request_timeout=30000,
            save_userbrowser=False,
            session={
                "id": "id",
                "prefetch_userbrowser": True,
                "retry": True,
                "timeout": 1,
            },
            skill="dynamic-content",
            skip_ubct=False,
            state="CA",
            tag="campaign-2024-q1",
            template={
                "name": "x",
                "params": {"foo": "bar"},
            },
            type="generic",
            userbrowser_creation_template_rendered={
                "id": "id",
                "allowed_parameter_names": ["x"],
                "render_flow_rendered": [{"foo": "bar"}],
            },
        )
        assert_matches_type(V2ExtractResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_extract(self, client: Nimbleway) -> None:
        response = client.v2.with_raw_response.extract(
            url="https://example.com/page",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = response.parse()
        assert_matches_type(V2ExtractResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_extract(self, client: Nimbleway) -> None:
        with client.v2.with_streaming_response.extract(
            url="https://example.com/page",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = response.parse()
            assert_matches_type(V2ExtractResponse, v2, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_map(self, client: Nimbleway) -> None:
        v2 = client.v2.map(
            url="url",
        )
        assert_matches_type(V2MapResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_map_with_all_params(self, client: Nimbleway) -> None:
        v2 = client.v2.map(
            url="url",
            country="US",
            domain_filter="all",
            limit=1000,
            locale="en-US",
            sitemap="include",
        )
        assert_matches_type(V2MapResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_map(self, client: Nimbleway) -> None:
        response = client.v2.with_raw_response.map(
            url="url",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = response.parse()
        assert_matches_type(V2MapResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_map(self, client: Nimbleway) -> None:
        with client.v2.with_streaming_response.map(
            url="url",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = response.parse()
            assert_matches_type(V2MapResponse, v2, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncV2:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_extract(self, async_client: AsyncNimbleway) -> None:
        v2 = await async_client.v2.extract(
            url="https://example.com/page",
        )
        assert_matches_type(V2ExtractResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_extract_with_all_params(self, async_client: AsyncNimbleway) -> None:
        v2 = await async_client.v2.extract(
            url="https://example.com/page",
            browser="chrome",
            city="Los Angeles",
            client_timeout=25000,
            consent_header=True,
            cookies=[
                {
                    "creation": "creation",
                    "domain": "domain",
                    "expires": "expires",
                    "extensions": ["string"],
                    "host_only": True,
                    "http_only": True,
                    "last_accessed": "lastAccessed",
                    "max_age": "Infinity",
                    "name": "name",
                    "path": "path",
                    "path_is_default": True,
                    "same_site": "strict",
                    "secure": True,
                    "value": "value",
                }
            ],
            country="US",
            device="desktop",
            disable_ip_check=False,
            driver="vx8",
            dynamic_parser={"myParser": "bar"},
            expected_status_codes=[200, 201],
            format="json",
            headers={
                "User-Agent": "CustomBot/1.0",
                "Accept-Language": "en-US",
            },
            http2=True,
            ip6=False,
            is_xhr=True,
            locale="en-US",
            markdown=False,
            metadata={
                "account_name": "acme-corp",
                "definition_id": 456,
                "definition_name": "product-scraper",
                "endpoint": "/api/v2/scrape",
                "execution_id": "exec-abc123",
                "flowit_task_id": "task-xyz789",
                "input_id": "input-123",
                "pipeline_execution_id": 12345,
                "query_template_id": "template-qry-001",
                "source": "web-app",
                "template_id": 789,
                "template_name": "e-commerce-template",
            },
            method="GET",
            native_mode="requester",
            network_capture=[
                {
                    "method": "GET",
                    "resource_type": "document",
                    "status_code": 100,
                    "url": {
                        "value": "value",
                        "type": "exact",
                    },
                    "validation": True,
                    "wait_for_requests_count": 0,
                    "wait_for_requests_count_timeout": 1,
                }
            ],
            no_html=False,
            no_userbrowser=False,
            os="windows",
            parse=True,
            parse_options={"merge_dynamic": True},
            parser={"myParser": "bar"},
            proxy_provider="brightdata",
            proxy_providers={
                "brightdata": 70,
                "oxylabs": 30,
            },
            query_template={
                "id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                "api_type": "WEB",
                "pagination": {"next_page_params": {"foo": "bar"}},
                "params": {"foo": "bar"},
            },
            raw_headers=True,
            referrer_type="random",
            render=True,
            render_flow=[{"wait": "bar"}, {"click": "bar"}],
            render_options={
                "adblock": True,
                "blocked_domains": ["ads.example.com", "tracker.com"],
                "browser_engine": "chrome",
                "cache": False,
                "connector_type": "puppeteer",
                "disabled_resources": ["image", "stylesheet"],
                "enable_2captcha": True,
                "extensions": ["extension-id-1", "extension-id-2"],
                "fingerprint_id": "fp-abc123",
                "hackium_configuration": {
                    "collect_logs": True,
                    "do_not_fix_math_salt": True,
                    "enable_document_element_spoof": True,
                    "enable_document_has_focus": True,
                    "enable_fake_navigation_history": True,
                    "enable_key_ordering": True,
                    "enable_sniffer": True,
                    "enable_verbose_logs": True,
                },
                "headless": True,
                "include_iframes": True,
                "load_local_storage": True,
                "local_storage_keys_to_load": ["authToken", "userId"],
                "mouse_strategy": "linear",
                "no_accept_encoding": True,
                "override_permissions": True,
                "random_header_order": True,
                "render_type": "domcontentloaded",
                "store_local_storage": True,
                "timeout": 30000,
                "typing_interval": 100,
                "typing_strategy": "simple",
                "userbrowser": True,
                "wait_until": "networkidle2",
                "with_performance_metrics": True,
            },
            request_timeout=30000,
            save_userbrowser=False,
            session={
                "id": "id",
                "prefetch_userbrowser": True,
                "retry": True,
                "timeout": 1,
            },
            skill="dynamic-content",
            skip_ubct=False,
            state="CA",
            tag="campaign-2024-q1",
            template={
                "name": "x",
                "params": {"foo": "bar"},
            },
            type="generic",
            userbrowser_creation_template_rendered={
                "id": "id",
                "allowed_parameter_names": ["x"],
                "render_flow_rendered": [{"foo": "bar"}],
            },
        )
        assert_matches_type(V2ExtractResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_extract(self, async_client: AsyncNimbleway) -> None:
        response = await async_client.v2.with_raw_response.extract(
            url="https://example.com/page",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = await response.parse()
        assert_matches_type(V2ExtractResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_extract(self, async_client: AsyncNimbleway) -> None:
        async with async_client.v2.with_streaming_response.extract(
            url="https://example.com/page",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = await response.parse()
            assert_matches_type(V2ExtractResponse, v2, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_map(self, async_client: AsyncNimbleway) -> None:
        v2 = await async_client.v2.map(
            url="url",
        )
        assert_matches_type(V2MapResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_map_with_all_params(self, async_client: AsyncNimbleway) -> None:
        v2 = await async_client.v2.map(
            url="url",
            country="US",
            domain_filter="all",
            limit=1000,
            locale="en-US",
            sitemap="include",
        )
        assert_matches_type(V2MapResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_map(self, async_client: AsyncNimbleway) -> None:
        response = await async_client.v2.with_raw_response.map(
            url="url",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = await response.parse()
        assert_matches_type(V2MapResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_map(self, async_client: AsyncNimbleway) -> None:
        async with async_client.v2.with_streaming_response.map(
            url="url",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = await response.parse()
            assert_matches_type(V2MapResponse, v2, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import TYPE_CHECKING, Dict, List, Union, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["CrawlCrawlResponse", "CrawlOptions", "CrawlOptionsCallback", "CrawlOptionsCallbackUnionMember0", "Task"]


class CrawlOptionsCallbackUnionMember0(BaseModel):
    url: str

    events: Optional[List[Literal["started", "page", "completed", "failed"]]] = None

    headers: Optional[Dict[str, str]] = None

    metadata: Optional[Dict[str, object]] = None


CrawlOptionsCallback: TypeAlias = Union[CrawlOptionsCallbackUnionMember0, str]


class CrawlOptions(BaseModel):
    allow_external_links: bool

    allow_subdomains: bool

    crawl_entire_domain: bool

    ignore_query_parameters: bool

    limit: int

    max_discovery_depth: int

    sitemap: Literal["skip", "include", "only"]

    callback: Optional[CrawlOptionsCallback] = None

    exclude_paths: Optional[List[str]] = None

    include_paths: Optional[List[str]] = None

    if TYPE_CHECKING:
        # Some versions of Pydantic <2.8.0 have a bug and don’t allow assigning a
        # value to this field, so for compatibility we avoid doing it at runtime.
        __pydantic_extra__: Dict[str, object] = FieldInfo(init=False)  # pyright: ignore[reportIncompatibleVariableOverride]

        # Stub to indicate that arbitrary properties are accepted.
        # To access properties that are not valid identifiers you can use `getattr`, e.g.
        # `getattr(obj, '$type')`
        def __getattr__(self, attr: str) -> object: ...
    else:
        __pydantic_extra__: Dict[str, object]


class Task(BaseModel):
    crawl_id: str

    status: Literal["pending", "completed", "failed"]

    webit_task_id: str

    created_at: Union[str, Dict[str, object], None] = None

    updated_at: Union[str, Dict[str, object], None] = None


class CrawlCrawlResponse(BaseModel):
    id: str

    account_name: str

    crawl_options: CrawlOptions

    created_at: Union[str, Dict[str, object]]

    status: Literal["queued", "running", "succeeded", "failed", "canceled"]

    updated_at: Union[str, Dict[str, object]]

    url: str

    completed: Optional[float] = None

    completed_at: Union[str, Dict[str, object], None] = None

    encrypted_token: Optional[str] = None

    extract_options: Optional[Dict[str, object]] = None

    failed: Optional[float] = None

    name: Optional[str] = None

    pending: Optional[float] = None

    tasks: Optional[List[Task]] = None

    total: Optional[float] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["V2MapResponse", "Link"]


class Link(BaseModel):
    url: str

    description: Optional[str] = None

    title: Optional[str] = None


class V2MapResponse(BaseModel):
    """Response schema for map requests."""

    links: List[Link]
    """Array of mapped links with optional titles and descriptions."""

    success: bool
    """Indicates if the map request was successful."""

    task_id: str
    """Unique identifier for the map task."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .agent_get_params import AgentGetParams as AgentGetParams
from .crawl_list_params import CrawlListParams as CrawlListParams
from .agent_async_params import AgentAsyncParams as AgentAsyncParams
from .agent_get_response import AgentGetResponse as AgentGetResponse
from .crawl_crawl_params import CrawlCrawlParams as CrawlCrawlParams
from .crawl_get_response import CrawlGetResponse as CrawlGetResponse
from .crawl_list_response import CrawlListResponse as CrawlListResponse
from .agent_async_response import AgentAsyncResponse as AgentAsyncResponse
from .crawl_crawl_response import CrawlCrawlResponse as CrawlCrawlResponse
from .crawl_cancel_response import CrawlCancelResponse as CrawlCancelResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["AgentAsyncResponse"]


class AgentAsyncResponse(BaseModel):
    status: Literal["success"]

    task: Dict[str, object]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Union, Iterable, Optional
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = [
    "V2ExtractParams",
    "Browser",
    "BrowserUnionMember1",
    "CookiesUnionMember0",
    "Metadata",
    "NetworkCapture",
    "NetworkCaptureURL",
    "ParseOptions",
    "QueryTemplate",
    "QueryTemplatePagination",
    "QueryTemplatePaginationNextPageParams",
    "QueryTemplatePaginationUnionMember1",
    "RenderOptions",
    "RenderOptionsHackiumConfiguration",
    "Session",
    "Template",
    "UserbrowserCreationTemplateRendered",
]


class V2ExtractParams(TypedDict, total=False):
    url: Required[str]
    """Target URL to scrape"""

    browser: Browser
    """Browser type to emulate"""

    city: str
    """City for geolocation"""

    client_timeout: float
    """Client-side timeout in milliseconds"""

    consent_header: bool
    """Whether to automatically handle cookie consent headers"""

    cookies: Union[Iterable[CookiesUnionMember0], str]
    """Browser cookies as array of cookie objects"""

    country: Literal[
        "AD",
        "AE",
        "AF",
        "AG",
        "AI",
        "AL",
        "AM",
        "AO",
        "AQ",
        "AR",
        "AS",
        "AT",
        "AU",
        "AW",
        "AX",
        "AZ",
        "BA",
        "BB",
        "BD",
        "BE",
        "BF",
        "BG",
        "BH",
        "BI",
        "BJ",
        "BL",
        "BM",
        "BN",
        "BO",
        "BQ",
        "BR",
        "BS",
        "BT",
        "BV",
        "BW",
        "BY",
        "BZ",
        "CA",
        "CC",
        "CD",
        "CF",
        "CG",
        "CH",
        "CI",
        "CK",
        "CL",
        "CM",
        "CN",
        "CO",
        "CR",
        "CU",
        "CV",
        "CW",
        "CX",
        "CY",
        "CZ",
        "DE",
        "DJ",
        "DK",
        "DM",
        "DO",
        "DZ",
        "EC",
        "EE",
        "EG",
        "EH",
        "ER",
        "ES",
        "ET",
        "FI",
        "FJ",
        "FK",
        "FM",
        "FO",
        "FR",
        "GA",
        "GB",
        "GD",
        "GE",
        "GF",
        "GG",
        "GH",
        "GI",
        "GL",
        "GM",
        "GN",
        "GP",
        "GQ",
        "GR",
        "GS",
        "GT",
        "GU",
        "GW",
        "GY",
        "HK",
        "HM",
        "HN",
        "HR",
        "HT",
        "HU",
        "ID",
        "IE",
        "IL",
        "IM",
        "IN",
        "IO",
        "IQ",
        "IR",
        "IS",
        "IT",
        "JE",
        "JM",
        "JO",
        "JP",
        "KE",
        "KG",
        "KH",
        "KI",
        "KM",
        "KN",
        "KP",
        "KR",
        "KW",
        "KY",
        "KZ",
        "LA",
        "LB",
        "LC",
        "LI",
        "LK",
        "LR",
        "LS",
        "LT",
        "LU",
        "LV",
        "LY",
        "MA",
        "MC",
        "MD",
        "ME",
        "MF",
        "MG",
        "MH",
        "MK",
        "ML",
        "MM",
        "MN",
        "MO",
        "MP",
        "MQ",
        "MR",
        "MS",
        "MT",
        "MU",
        "MV",
        "MW",
        "MX",
        "MY",
        "MZ",
        "NA",
        "NC",
        "NE",
        "NF",
        "NG",
        "NI",
        "NL",
        "NO",
        "NP",
        "NR",
        "NU",
        "NZ",
        "OM",
        "PA",
        "PE",
        "PF",
        "PG",
        "PH",
        "PK",
        "PL",
        "PM",
        "PN",
        "PR",
        "PS",
        "PT",
        "PW",
        "PY",
        "QA",
        "RE",
        "RO",
        "RS",
        "RU",
        "RW",
        "SA",
        "SB",
        "SC",
        "SD",
        "SE",
        "SG",
        "SH",
        "SI",
        "SJ",
        "SK",
        "SL",
        "SM",
        "SN",
        "SO",
        "SR",
        "SS",
        "ST",
        "SV",
        "SX",
        "SY",
        "SZ",
        "TC",
        "TD",
        "TF",
        "TG",
        "TH",
        "TJ",
        "TK",
        "TL",
        "TM",
        "TN",
        "TO",
        "TR",
        "TT",
        "TV",
        "TW",
        "TZ",
        "UA",
        "UG",
        "UM",
        "US",
        "UY",
        "UZ",
        "VA",
        "VC",
        "VE",
        "VG",
        "VI",
        "VN",
        "VU",
        "WF",
        "WS",
        "XK",
        "YE",
        "YT",
        "ZA",
        "ZM",
        "ZW",
        "ALL",
    ]
    """Country code for geolocation and proxy selection"""

    device: Literal["desktop", "mobile", "tablet"]
    """Device type for browser emulation"""

    disable_ip_check: bool
    """Whether to disable IP address validation"""

    driver: Literal["vx6", "vx8", "vx8-pro", "vx10", "vx10-pro", "vx12", "vx12-pro"]
    """Browser driver to use"""

    dynamic_parser: Dict[str, object]
    """Custom parser configuration as a key-value map"""

    expected_status_codes: Iterable[int]
    """Expected HTTP status codes for successful requests"""

    format: Literal["json", "html", "csv", "raw", "json-lines", "markdown"]
    """Response format"""

    headers: Dict[str, Union[str, SequenceNotStr[str], None]]
    """Custom HTTP headers to include in the request"""

    http2: bool
    """Whether to use HTTP/2 protocol"""

    ip6: bool
    """Whether to use IPv6 for the request"""

    is_xhr: bool
    """Whether to emulate XMLHttpRequest behavior"""

    locale: Literal[
        "aa-DJ",
        "aa-ER",
        "aa-ET",
        "af",
        "af-NA",
        "af-ZA",
        "ak",
        "ak-GH",
        "am",
        "am-ET",
        "an-ES",
        "ar",
        "ar-AE",
        "ar-BH",
        "ar-DZ",
        "ar-EG",
        "ar-IN",
        "ar-IQ",
        "ar-JO",
        "ar-KW",
        "ar-LB",
        "ar-LY",
        "ar-MA",
        "ar-OM",
        "ar-QA",
        "ar-SA",
        "ar-SD",
        "ar-SY",
        "ar-TN",
        "ar-YE",
        "as",
        "as-IN",
        "asa",
        "asa-TZ",
        "ast-ES",
        "az",
        "az-AZ",
        "az-Cyrl",
        "az-Cyrl-AZ",
        "az-Latn",
        "az-Latn-AZ",
        "be",
        "be-BY",
        "bem",
        "bem-ZM",
        "ber-DZ",
        "ber-MA",
        "bez",
        "bez-TZ",
        "bg",
        "bg-BG",
        "bho-IN",
        "bm",
        "bm-ML",
        "bn",
        "bn-BD",
        "bn-IN",
        "bo",
        "bo-CN",
        "bo-IN",
        "br-FR",
        "brx-IN",
        "bs",
        "bs-BA",
        "byn-ER",
        "ca",
        "ca-AD",
        "ca-ES",
        "ca-FR",
        "ca-IT",
        "cgg",
        "cgg-UG",
        "chr",
        "chr-US",
        "crh-UA",
        "cs",
        "cs-CZ",
        "csb-PL",
        "cv-RU",
        "cy",
        "cy-GB",
        "da",
        "da-DK",
        "dav",
        "dav-KE",
        "de",
        "de-AT",
        "de-BE",
        "de-CH",
        "de-DE",
        "de-LI",
        "de-LU",
        "dv-MV",
        "dz-BT",
        "ebu",
        "ebu-KE",
        "ee",
        "ee-GH",
        "ee-TG",
        "el",
        "el-CY",
        "el-GR",
        "en",
        "en-AG",
        "en-AS",
        "en-AU",
        "en-BE",
        "en-BW",
        "en-BZ",
        "en-CA",
        "en-DK",
        "en-GB",
        "en-GU",
        "en-HK",
        "en-IE",
        "en-IN",
        "en-JM",
        "en-MH",
        "en-MP",
        "en-MT",
        "en-MU",
        "en-NA",
        "en-NG",
        "en-NZ",
        "en-PH",
        "en-PK",
        "en-SG",
        "en-TT",
        "en-UM",
        "en-US",
        "en-VI",
        "en-ZA",
        "en-ZM",
        "en-ZW",
        "eo",
        "es",
        "es-419",
        "es-AR",
        "es-BO",
        "es-CL",
        "es-CO",
        "es-CR",
        "es-CU",
        "es-DO",
        "es-EC",
        "es-ES",
        "es-GQ",
        "es-GT",
        "es-HN",
        "es-MX",
        "es-NI",
        "es-PA",
        "es-PE",
        "es-PR",
        "es-PY",
        "es-SV",
        "es-US",
        "es-UY",
        "es-VE",
        "et",
        "et-EE",
        "eu",
        "eu-ES",
        "fa",
        "fa-AF",
        "fa-IR",
        "ff",
        "ff-SN",
        "fi",
        "fi-FI",
        "fil",
        "fil-PH",
        "fo",
        "fo-FO",
        "fr",
        "fr-BE",
        "fr-BF",
        "fr-BI",
        "fr-BJ",
        "fr-BL",
        "fr-CA",
        "fr-CD",
        "fr-CF",
        "fr-CG",
        "fr-CH",
        "fr-CI",
        "fr-CM",
        "fr-DJ",
        "fr-FR",
        "fr-GA",
        "fr-GN",
        "fr-GP",
        "fr-GQ",
        "fr-KM",
        "fr-LU",
        "fr-MC",
        "fr-MF",
        "fr-MG",
        "fr-ML",
        "fr-MQ",
        "fr-NE",
        "fr-RE",
        "fr-RW",
        "fr-SN",
        "fr-TD",
        "fr-TG",
        "fur-IT",
        "fy-DE",
        "fy-NL",
        "ga",
        "ga-IE",
        "gd-GB",
        "gez-ER",
        "gez-ET",
        "gl",
        "gl-ES",
        "gsw",
        "gsw-CH",
        "gu",
        "gu-IN",
        "guz",
        "guz-KE",
        "gv",
        "gv-GB",
        "ha",
        "ha-Latn",
        "ha-Latn-GH",
        "ha-Latn-NE",
        "ha-Latn-NG",
        "ha-NG",
        "haw",
        "haw-US",
        "he",
        "he-IL",
        "hi",
        "hi-IN",
        "hne-IN",
        "hr",
        "hr-HR",
        "hsb-DE",
        "ht-HT",
        "hu",
        "hu-HU",
        "hy",
        "hy-AM",
        "id",
        "id-ID",
        "ig",
        "ig-NG",
        "ii",
        "ii-CN",
        "ik-CA",
        "is",
        "is-IS",
        "it",
        "it-CH",
        "it-IT",
        "iu-CA",
        "iw-IL",
        "ja",
        "ja-JP",
        "jmc",
        "jmc-TZ",
        "ka",
        "ka-GE",
        "kab",
        "kab-DZ",
        "kam",
        "kam-KE",
        "kde",
        "kde-TZ",
        "kea",
        "kea-CV",
        "khq",
        "khq-ML",
        "ki",
        "ki-KE",
        "kk",
        "kk-Cyrl",
        "kk-Cyrl-KZ",
        "kk-KZ",
        "kl",
        "kl-GL",
        "kln",
        "kln-KE",
        "km",
        "km-KH",
        "kn",
        "kn-IN",
        "ko",
        "ko-KR",
        "kok",
        "kok-IN",
        "ks-IN",
        "ku-TR",
        "kw",
        "kw-GB",
        "ky-KG",
        "lag",
        "lag-TZ",
        "lb-LU",
        "lg",
        "lg-UG",
        "li-BE",
        "li-NL",
        "lij-IT",
        "lo-LA",
        "lt",
        "lt-LT",
        "luo",
        "luo-KE",
        "luy",
        "luy-KE",
        "lv",
        "lv-LV",
        "mag-IN",
        "mai-IN",
        "mas",
        "mas-KE",
        "mas-TZ",
        "mer",
        "mer-KE",
        "mfe",
        "mfe-MU",
        "mg",
        "mg-MG",
        "mhr-RU",
        "mi-NZ",
        "mk",
        "mk-MK",
        "ml",
        "ml-IN",
        "mn-MN",
        "mr",
        "mr-IN",
        "ms",
        "ms-BN",
        "ms-MY",
        "mt",
        "mt-MT",
        "my",
        "my-MM",
        "nan-TW",
        "naq",
        "naq-NA",
        "nb",
        "nb-NO",
        "nd",
        "nd-ZW",
        "nds-DE",
        "nds-NL",
        "ne",
        "ne-IN",
        "ne-NP",
        "nl",
        "nl-AW",
        "nl-BE",
        "nl-NL",
        "nn",
        "nn-NO",
        "nr-ZA",
        "nso-ZA",
        "nyn",
        "nyn-UG",
        "oc-FR",
        "om",
        "om-ET",
        "om-KE",
        "or",
        "or-IN",
        "os-RU",
        "pa",
        "pa-Arab",
        "pa-Arab-PK",
        "pa-Guru",
        "pa-Guru-IN",
        "pa-IN",
        "pa-PK",
        "pap-AN",
        "pl",
        "pl-PL",
        "ps",
        "ps-AF",
        "pt",
        "pt-BR",
        "pt-GW",
        "pt-MZ",
        "pt-PT",
        "rm",
        "rm-CH",
        "ro",
        "ro-MD",
        "ro-RO",
        "rof",
        "rof-TZ",
        "ru",
        "ru-MD",
        "ru-RU",
        "ru-UA",
        "rw",
        "rw-RW",
        "rwk",
        "rwk-TZ",
        "sa-IN",
        "saq",
        "saq-KE",
        "sc-IT",
        "sd-IN",
        "se-NO",
        "seh",
        "seh-MZ",
        "ses",
        "ses-ML",
        "sg",
        "sg-CF",
        "shi",
        "shi-Latn",
        "shi-Latn-MA",
        "shi-Tfng",
        "shi-Tfng-MA",
        "shs-CA",
        "si",
        "si-LK",
        "sid-ET",
        "sk",
        "sk-SK",
        "sl",
        "sl-SI",
        "sn",
        "sn-ZW",
        "so",
        "so-DJ",
        "so-ET",
        "so-KE",
        "so-SO",
        "sq",
        "sq-AL",
        "sq-MK",
        "sr",
        "sr-Cyrl",
        "sr-Cyrl-BA",
        "sr-Cyrl-ME",
        "sr-Cyrl-RS",
        "sr-Latn",
        "sr-Latn-BA",
        "sr-Latn-ME",
        "sr-Latn-RS",
        "sr-ME",
        "sr-RS",
        "ss-ZA",
        "st-ZA",
        "sv",
        "sv-FI",
        "sv-SE",
        "sw",
        "sw-KE",
        "sw-TZ",
        "ta",
        "ta-IN",
        "ta-LK",
        "te",
        "te-IN",
        "teo",
        "teo-KE",
        "teo-UG",
        "tg-TJ",
        "th",
        "th-TH",
        "ti",
        "ti-ER",
        "ti-ET",
        "tig-ER",
        "tk-TM",
        "tl-PH",
        "tn-ZA",
        "to",
        "to-TO",
        "tr",
        "tr-CY",
        "tr-TR",
        "ts-ZA",
        "tt-RU",
        "tzm",
        "tzm-Latn",
        "tzm-Latn-MA",
        "ug-CN",
        "uk",
        "uk-UA",
        "unm-US",
        "ur",
        "ur-IN",
        "ur-PK",
        "uz",
        "uz-Arab",
        "uz-Arab-AF",
        "uz-Cyrl",
        "uz-Cyrl-UZ",
        "uz-Latn",
        "uz-Latn-UZ",
        "uz-UZ",
        "ve-ZA",
        "vi",
        "vi-VN",
        "vun",
        "vun-TZ",
        "wa-BE",
        "wae-CH",
        "wal-ET",
        "wo-SN",
        "xh-ZA",
        "xog",
        "xog-UG",
        "yi-US",
        "yo",
        "yo-NG",
        "yue-HK",
        "zh",
        "zh-CN",
        "zh-HK",
        "zh-Hans",
        "zh-Hans-CN",
        "zh-Hans-HK",
        "zh-Hans-MO",
        "zh-Hans-SG",
        "zh-Hant",
        "zh-Hant-HK",
        "zh-Hant-MO",
        "zh-Hant-TW",
        "zh-SG",
        "zh-TW",
        "zu",
        "zu-ZA",
        "auto",
    ]
    """Locale for browser language and region settings"""

    markdown: bool
    """Whether to return response in Markdown format"""

    metadata: Metadata
    """Structured metadata about the request execution context"""

    method: Literal["GET", "POST", "PUT", "PATCH", "DELETE"]
    """HTTP method for the request"""

    native_mode: Literal["requester", "apm", "direct"]
    """Native execution mode"""

    network_capture: Iterable[NetworkCapture]
    """Filters for capturing network traffic"""

    no_html: bool
    """Whether to exclude HTML from the response"""

    no_userbrowser: bool
    """Whether to disable browser-based rendering"""

    os: Literal["windows", "mac os", "linux", "android", "ios"]
    """Operating system to emulate"""

    parse: bool
    """Whether to parse the response content"""

    parse_options: ParseOptions
    """Configuration options for parsing behavior"""

    parser: Union[Dict[str, object], str]
    """Custom parser configuration as a key-value map"""

    proxy_provider: Literal[
        "brightdata",
        "oxylabs",
        "smartproxy",
        "proxit",
        "proxit_preprod",
        "local",
        "rayobyte",
        "always",
        "oculusproxies",
        "froxy",
        "packetstream",
        "911proxy",
        "direct911proxy",
        "thesocialproxy",
        "thesocialproxy2",
        "nimble-isp",
        "nimble-isp-mobile",
        "proxit-linux",
        "proxit-macos",
        "proxit-windows",
        "proxit-rental",
        "ipfoxy",
        "brightup",
        "research",
    ]
    """Proxy provider to use for the request"""

    proxy_providers: Dict[str, float]
    """Weighted distribution of proxy providers"""

    query_template: QueryTemplate
    """Query template configuration for structured data extraction"""

    raw_headers: bool
    """Whether to return raw HTTP headers in response"""

    referrer_type: Literal["random", "no-referer", "same-origin", "google", "bing", "facebook", "twitter", "instagram"]
    """Referrer policy for the request"""

    render: bool
    """Whether to render JavaScript content using a browser"""

    render_flow: Iterable[Dict[str, object]]
    """Array of actions to perform during browser rendering"""

    render_options: RenderOptions

    request_timeout: float
    """Request timeout in milliseconds"""

    save_userbrowser: bool
    """Whether to save the userbrowser session for reuse"""

    session: Session

    skill: Union[str, SequenceNotStr[str]]
    """Skills or capabilities required for the request"""

    skip_ubct: bool
    """Whether to skip userbrowser creation template processing"""

    state: Literal[
        "AL",
        "AK",
        "AS",
        "AZ",
        "AR",
        "CA",
        "CO",
        "CT",
        "DE",
        "DC",
        "FL",
        "GA",
        "GU",
        "HI",
        "ID",
        "IL",
        "IN",
        "IA",
        "KS",
        "KY",
        "LA",
        "ME",
        "MD",
        "MA",
        "MI",
        "MN",
        "MS",
        "MO",
        "MT",
        "NE",
        "NV",
        "NH",
        "NJ",
        "NM",
        "NY",
        "NC",
        "ND",
        "MP",
        "OH",
        "OK",
        "OR",
        "PA",
        "PR",
        "RI",
        "SC",
        "SD",
        "TN",
        "TX",
        "UT",
        "VT",
        "VA",
        "VI",
        "WA",
        "WV",
        "WI",
        "WY",
    ]
    """US state for geolocation (only valid when country is US)"""

    tag: str
    """User-defined tag for request identification"""

    template: Template
    """Userbrowser creation template configuration"""

    type: str
    """Type of query or scraping template"""

    userbrowser_creation_template_rendered: UserbrowserCreationTemplateRendered
    """Pre-rendered userbrowser creation template configuration"""


class BrowserUnionMember1(TypedDict, total=False):
    name: Required[Literal["chrome", "firefox"]]

    version: str
    """Specific browser version to emulate"""


Browser: TypeAlias = Union[Literal["chrome", "firefox"], BrowserUnionMember1]


class CookiesUnionMember0Typed(TypedDict, total=False):
    creation: Optional[str]

    domain: Optional[str]

    expires: str

    extensions: Optional[SequenceNotStr[str]]

    host_only: Annotated[Optional[bool], PropertyInfo(alias="hostOnly")]

    http_only: Annotated[Optional[bool], PropertyInfo(alias="httpOnly")]

    last_accessed: Annotated[Optional[str], PropertyInfo(alias="lastAccessed")]

    max_age: Annotated[Union[Literal["Infinity", "-Infinity"], float, None], PropertyInfo(alias="maxAge")]

    name: str

    path: Optional[str]

    path_is_default: Annotated[Optional[bool], PropertyInfo(alias="pathIsDefault")]

    same_site: Annotated[Literal["strict", "lax", "none"], PropertyInfo(alias="sameSite")]

    secure: bool

    value: str


CookiesUnionMember0: TypeAlias = Union[CookiesUnionMember0Typed, Dict[str, object]]


class Metadata(TypedDict, total=False):
    """Structured metadata about the request execution context"""

    account_name: str
    """Account name associated with the request"""

    definition_id: int
    """Definition identifier"""

    definition_name: str
    """Name of the definition"""

    endpoint: str
    """API endpoint being called"""

    execution_id: str
    """Unique identifier for this execution"""

    flowit_task_id: str
    """FlowIt task identifier"""

    input_id: str
    """Input data identifier"""

    pipeline_execution_id: int
    """Identifier for the pipeline execution"""

    query_template_id: str
    """Query template identifier"""

    source: str
    """Source system or application making the request"""

    template_id: int
    """Template identifier"""

    template_name: str
    """Name of the template"""


class NetworkCaptureURL(TypedDict, total=False):
    value: Required[str]

    type: Literal["exact", "contains"]


class NetworkCapture(TypedDict, total=False):
    method: Literal["GET", "HEAD", "POST", "PUT", "DELETE", "CONNECT", "OPTIONS", "TRACE", "PATCH"]

    resource_type: Union[str, SequenceNotStr[str]]
    """Resource type for network capture filtering"""

    status_code: Union[float, Iterable[float]]

    url: NetworkCaptureURL

    validation: bool

    wait_for_requests_count: float

    wait_for_requests_count_timeout: float


class ParseOptionsTyped(TypedDict, total=False):
    """Configuration options for parsing behavior"""

    merge_dynamic: bool
    """Whether to merge dynamic parsing results with static results"""


ParseOptions: TypeAlias = Union[ParseOptionsTyped, Dict[str, object]]


class QueryTemplatePaginationNextPageParams(TypedDict, total=False):
    next_page_params: Required[Dict[str, object]]


class QueryTemplatePaginationUnionMember1(TypedDict, total=False):
    next_page_params: Required[Dict[str, object]]


QueryTemplatePagination: TypeAlias = Union[
    QueryTemplatePaginationNextPageParams, Iterable[QueryTemplatePaginationUnionMember1]
]


class QueryTemplateTyped(TypedDict, total=False):
    """Query template configuration for structured data extraction"""

    id: Required[str]

    api_type: Literal["WEB", "SERP", "SOCIAL"]

    pagination: QueryTemplatePagination

    params: Dict[str, object]


QueryTemplate: TypeAlias = Union[QueryTemplateTyped, Dict[str, object]]


class RenderOptionsHackiumConfiguration(TypedDict, total=False):
    """Configuration for Hackium browser modifications"""

    collect_logs: bool

    do_not_fix_math_salt: bool

    enable_document_element_spoof: bool

    enable_document_has_focus: bool

    enable_fake_navigation_history: bool

    enable_key_ordering: bool

    enable_sniffer: bool

    enable_verbose_logs: bool


class RenderOptions(TypedDict, total=False):
    adblock: bool
    """Whether to enable ad blocking"""

    blocked_domains: SequenceNotStr[str]
    """Domains to block from loading"""

    browser_engine: Union[Literal["chrome", "hackium", "firefox", "hackfox"], Dict[str, float]]
    """Browser engine to use, or weighted distribution of engines"""

    cache: bool
    """Whether to enable browser caching"""

    connector_type: Literal["puppeteer", "puppeteer-cdp", "puppeteer-bidi", "webit-cdp", "playwright"]
    """Type of browser connector to use"""

    disabled_resources: List[
        Literal[
            "other",
            "document",
            "stylesheet",
            "image",
            "media",
            "font",
            "script",
            "texttrack",
            "xhr",
            "fetch",
            "eventsource",
            "websocket",
            "manifest",
            "signedexchange",
            "ping",
            "cspviolationreport",
            "prefetch",
            "preflight",
            "fedcm",
        ]
    ]
    """Types of resources to block from loading"""

    enable_2captcha: bool
    """Whether to use 2Captcha service for solving captchas"""

    extensions: SequenceNotStr[str]
    """Browser extensions to load"""

    fingerprint_id: str
    """Fingerprint identifier for browser customization"""

    hackium_configuration: RenderOptionsHackiumConfiguration
    """Configuration for Hackium browser modifications"""

    headless: bool
    """Whether to run browser in headless mode"""

    include_iframes: bool
    """Whether to include iframe content in the result"""

    load_local_storage: bool
    """Whether to load previously stored localStorage data"""

    local_storage_keys_to_load: SequenceNotStr[str]
    """Specific localStorage keys to load"""

    mouse_strategy: Literal["linear", "ghost-cursor", "windmouse"]
    """Strategy for simulating mouse movements"""

    no_accept_encoding: bool
    """Disable content encoding to avoid cached responses"""

    override_permissions: bool
    """Whether to override default browser permissions"""

    random_header_order: bool
    """Whether to randomize HTTP header order"""

    render_type: Literal["domcontentloaded", "load", "idle0", "networkidle0", "idle2", "networkidle2", "navigate"]
    """Type of render completion to wait for"""

    store_local_storage: bool
    """Whether to store localStorage data for future sessions"""

    timeout: float
    """Maximum time in milliseconds to wait for page render"""

    typing_interval: float
    """Interval in milliseconds between key presses"""

    typing_strategy: Literal["simple", "distribution"]
    """Strategy for simulating keyboard typing"""

    userbrowser: bool
    """Whether to use a persistent browser session"""

    wait_until: Literal["load", "domcontentloaded", "idle0", "idle2", "networkidle0", "networkidle2", "navigate"]
    """Browser event to wait for before considering page loaded"""

    with_performance_metrics: bool
    """Whether to collect performance metrics during rendering"""


class Session(TypedDict, total=False):
    id: str

    prefetch_userbrowser: bool

    retry: bool

    timeout: float


class Template(TypedDict, total=False):
    """Userbrowser creation template configuration"""

    name: Required[str]

    params: Dict[str, object]


class UserbrowserCreationTemplateRendered(TypedDict, total=False):
    """Pre-rendered userbrowser creation template configuration"""

    id: Required[str]

    allowed_parameter_names: Required[SequenceNotStr[str]]

    render_flow_rendered: Required[Iterable[Dict[str, object]]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from nimbleway_webit import Nimbleway, AsyncNimbleway
from nimbleway_webit.types.v2 import AgentGetResponse, AgentAsyncResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAgent:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_async_overload_1(self, client: Nimbleway) -> None:
        agent = client.v2.agent.async_(
            params={"foo": "bar"},
            template="template",
        )
        assert_matches_type(AgentAsyncResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_async_with_all_params_overload_1(self, client: Nimbleway) -> None:
        agent = client.v2.agent.async_(
            params={"foo": "bar"},
            template="template",
            localization=True,
        )
        assert_matches_type(AgentAsyncResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_async_overload_1(self, client: Nimbleway) -> None:
        response = client.v2.agent.with_raw_response.async_(
            params={"foo": "bar"},
            template="template",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        agent = response.parse()
        assert_matches_type(AgentAsyncResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_async_overload_1(self, client: Nimbleway) -> None:
        with client.v2.agent.with_streaming_response.async_(
            params={"foo": "bar"},
            template="template",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            agent = response.parse()
            assert_matches_type(AgentAsyncResponse, agent, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_async_overload_2(self, client: Nimbleway) -> None:
        agent = client.v2.agent.async_(
            agent="agent",
            params={"foo": "bar"},
        )
        assert_matches_type(AgentAsyncResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_async_with_all_params_overload_2(self, client: Nimbleway) -> None:
        agent = client.v2.agent.async_(
            agent="agent",
            params={"foo": "bar"},
            localization=True,
        )
        assert_matches_type(AgentAsyncResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_async_overload_2(self, client: Nimbleway) -> None:
        response = client.v2.agent.with_raw_response.async_(
            agent="agent",
            params={"foo": "bar"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        agent = response.parse()
        assert_matches_type(AgentAsyncResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_async_overload_2(self, client: Nimbleway) -> None:
        with client.v2.agent.with_streaming_response.async_(
            agent="agent",
            params={"foo": "bar"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            agent = response.parse()
            assert_matches_type(AgentAsyncResponse, agent, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_overload_1(self, client: Nimbleway) -> None:
        agent = client.v2.agent.get(
            params={"foo": "bar"},
            template="template",
        )
        assert_matches_type(AgentGetResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_with_all_params_overload_1(self, client: Nimbleway) -> None:
        agent = client.v2.agent.get(
            params={"foo": "bar"},
            template="template",
            localization=True,
        )
        assert_matches_type(AgentGetResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_overload_1(self, client: Nimbleway) -> None:
        response = client.v2.agent.with_raw_response.get(
            params={"foo": "bar"},
            template="template",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        agent = response.parse()
        assert_matches_type(AgentGetResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_overload_1(self, client: Nimbleway) -> None:
        with client.v2.agent.with_streaming_response.get(
            params={"foo": "bar"},
            template="template",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            agent = response.parse()
            assert_matches_type(AgentGetResponse, agent, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_overload_2(self, client: Nimbleway) -> None:
        agent = client.v2.agent.get(
            agent="agent",
            params={"foo": "bar"},
        )
        assert_matches_type(AgentGetResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_with_all_params_overload_2(self, client: Nimbleway) -> None:
        agent = client.v2.agent.get(
            agent="agent",
            params={"foo": "bar"},
            localization=True,
        )
        assert_matches_type(AgentGetResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_overload_2(self, client: Nimbleway) -> None:
        response = client.v2.agent.with_raw_response.get(
            agent="agent",
            params={"foo": "bar"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        agent = response.parse()
        assert_matches_type(AgentGetResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_overload_2(self, client: Nimbleway) -> None:
        with client.v2.agent.with_streaming_response.get(
            agent="agent",
            params={"foo": "bar"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            agent = response.parse()
            assert_matches_type(AgentGetResponse, agent, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncAgent:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_async_overload_1(self, async_client: AsyncNimbleway) -> None:
        agent = await async_client.v2.agent.async_(
            params={"foo": "bar"},
            template="template",
        )
        assert_matches_type(AgentAsyncResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_async_with_all_params_overload_1(self, async_client: AsyncNimbleway) -> None:
        agent = await async_client.v2.agent.async_(
            params={"foo": "bar"},
            template="template",
            localization=True,
        )
        assert_matches_type(AgentAsyncResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_async_overload_1(self, async_client: AsyncNimbleway) -> None:
        response = await async_client.v2.agent.with_raw_response.async_(
            params={"foo": "bar"},
            template="template",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        agent = await response.parse()
        assert_matches_type(AgentAsyncResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_async_overload_1(self, async_client: AsyncNimbleway) -> None:
        async with async_client.v2.agent.with_streaming_response.async_(
            params={"foo": "bar"},
            template="template",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            agent = await response.parse()
            assert_matches_type(AgentAsyncResponse, agent, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_async_overload_2(self, async_client: AsyncNimbleway) -> None:
        agent = await async_client.v2.agent.async_(
            agent="agent",
            params={"foo": "bar"},
        )
        assert_matches_type(AgentAsyncResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_async_with_all_params_overload_2(self, async_client: AsyncNimbleway) -> None:
        agent = await async_client.v2.agent.async_(
            agent="agent",
            params={"foo": "bar"},
            localization=True,
        )
        assert_matches_type(AgentAsyncResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_async_overload_2(self, async_client: AsyncNimbleway) -> None:
        response = await async_client.v2.agent.with_raw_response.async_(
            agent="agent",
            params={"foo": "bar"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        agent = await response.parse()
        assert_matches_type(AgentAsyncResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_async_overload_2(self, async_client: AsyncNimbleway) -> None:
        async with async_client.v2.agent.with_streaming_response.async_(
            agent="agent",
            params={"foo": "bar"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            agent = await response.parse()
            assert_matches_type(AgentAsyncResponse, agent, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_overload_1(self, async_client: AsyncNimbleway) -> None:
        agent = await async_client.v2.agent.get(
            params={"foo": "bar"},
            template="template",
        )
        assert_matches_type(AgentGetResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_with_all_params_overload_1(self, async_client: AsyncNimbleway) -> None:
        agent = await async_client.v2.agent.get(
            params={"foo": "bar"},
            template="template",
            localization=True,
        )
        assert_matches_type(AgentGetResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_overload_1(self, async_client: AsyncNimbleway) -> None:
        response = await async_client.v2.agent.with_raw_response.get(
            params={"foo": "bar"},
            template="template",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        agent = await response.parse()
        assert_matches_type(AgentGetResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_overload_1(self, async_client: AsyncNimbleway) -> None:
        async with async_client.v2.agent.with_streaming_response.get(
            params={"foo": "bar"},
            template="template",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            agent = await response.parse()
            assert_matches_type(AgentGetResponse, agent, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_overload_2(self, async_client: AsyncNimbleway) -> None:
        agent = await async_client.v2.agent.get(
            agent="agent",
            params={"foo": "bar"},
        )
        assert_matches_type(AgentGetResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_with_all_params_overload_2(self, async_client: AsyncNimbleway) -> None:
        agent = await async_client.v2.agent.get(
            agent="agent",
            params={"foo": "bar"},
            localization=True,
        )
        assert_matches_type(AgentGetResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_overload_2(self, async_client: AsyncNimbleway) -> None:
        response = await async_client.v2.agent.with_raw_response.get(
            agent="agent",
            params={"foo": "bar"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        agent = await response.parse()
        assert_matches_type(AgentGetResponse, agent, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_overload_2(self, async_client: AsyncNimbleway) -> None:
        async with async_client.v2.agent.with_streaming_response.get(
            agent="agent",
            params={"foo": "bar"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            agent = await response.parse()
            assert_matches_type(AgentGetResponse, agent, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union
from typing_extensions import Required, TypeAlias, TypedDict

__all__ = ["AgentAsyncParams", "ExtractTemplateBody", "AgentBody"]


class ExtractTemplateBody(TypedDict, total=False):
    params: Required[Dict[str, object]]

    template: Required[str]

    localization: bool


class AgentBody(TypedDict, total=False):
    agent: Required[str]

    params: Required[Dict[str, object]]

    localization: bool


AgentAsyncParams: TypeAlias = Union[ExtractTemplateBody, AgentBody]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = [
    "AgentGetResponse",
    "Data",
    "DataBrowserActions",
    "DataBrowserActionsResult",
    "DataBrowserActionsResultUnionMember0",
    "DataBrowserActionsResultUnionMember1",
    "DataNetworkCapture",
    "DataNetworkCaptureFilter",
    "DataNetworkCaptureFilterURL",
    "DataNetworkCaptureResult",
    "DataNetworkCaptureResultRequest",
    "DataNetworkCaptureResultResponse",
    "DataParsing",
    "DataParsingUnionMember0",
    "DataParsingUnionMember1",
    "DataRedirect",
    "Metadata",
    "Debug",
    "Pagination",
    "PaginationNextPageParams",
    "PaginationUnionMember1",
]


class DataBrowserActionsResultUnionMember0(BaseModel):
    duration: float

    name: str

    status: Literal["no-run", "in-progress", "done", "error", "skipped"]

    result: Optional[object] = None


class DataBrowserActionsResultUnionMember1(BaseModel):
    duration: float

    error: str

    name: str

    status: Literal["no-run", "in-progress", "done", "error", "skipped"]


DataBrowserActionsResult: TypeAlias = Union[DataBrowserActionsResultUnionMember0, DataBrowserActionsResultUnionMember1]


class DataBrowserActions(BaseModel):
    """The render flow browser actions status results."""

    results: List[DataBrowserActionsResult]

    success: bool


class DataNetworkCaptureFilterURL(BaseModel):
    type: Literal["exact", "contains"]

    value: str


class DataNetworkCaptureFilter(BaseModel):
    validation: bool

    wait_for_requests_count: float

    method: Optional[Literal["GET", "HEAD", "POST", "PUT", "DELETE", "CONNECT", "OPTIONS", "TRACE", "PATCH"]] = None

    resource_type: Union[
        Literal[
            "document",
            "stylesheet",
            "image",
            "media",
            "font",
            "script",
            "texttrack",
            "xhr",
            "fetch",
            "prefetch",
            "eventsource",
            "websocket",
            "manifest",
            "signedexchange",
            "ping",
            "cspviolationreport",
            "preflight",
            "other",
            "fedcm",
        ],
        List[
            Literal[
                "document",
                "stylesheet",
                "image",
                "media",
                "font",
                "script",
                "texttrack",
                "xhr",
                "fetch",
                "prefetch",
                "eventsource",
                "websocket",
                "manifest",
                "signedexchange",
                "ping",
                "cspviolationreport",
                "preflight",
                "other",
                "fedcm",
            ]
        ],
        None,
    ] = None
    """Resource type for network capture filtering"""

    status_code: Union[float, List[float], None] = None

    url: Optional[DataNetworkCaptureFilterURL] = None

    wait_for_requests_count_timeout: Optional[float] = None


class DataNetworkCaptureResultRequest(BaseModel):
    headers: Dict[str, str]

    method: str

    resource_type: Literal[
        "document",
        "stylesheet",
        "image",
        "media",
        "font",
        "script",
        "texttrack",
        "xhr",
        "fetch",
        "prefetch",
        "eventsource",
        "websocket",
        "manifest",
        "signedexchange",
        "ping",
        "cspviolationreport",
        "preflight",
        "other",
        "fedcm",
    ]
    """Resource type for network capture filtering"""

    url: str

    body: Optional[str] = None


class DataNetworkCaptureResultResponse(BaseModel):
    body: str

    headers: Dict[str, str]

    serialization: Literal["none", "base64"]

    status: float

    status_text: str


class DataNetworkCaptureResult(BaseModel):
    request: DataNetworkCaptureResultRequest

    response: DataNetworkCaptureResultResponse


class DataNetworkCapture(BaseModel):
    filter: DataNetworkCaptureFilter

    results: List[DataNetworkCaptureResult]

    error_message: Optional[str] = FieldInfo(alias="errorMessage", default=None)


class DataParsingUnionMember0(BaseModel):
    entities: Dict[str, object]

    status: Literal["success"]


class DataParsingUnionMember1(BaseModel):
    error: str

    status: Literal["error"]


DataParsing: TypeAlias = Union[DataParsingUnionMember0, DataParsingUnionMember1, Dict[str, object]]


class DataRedirect(BaseModel):
    status_code: float

    url: str


class Data(BaseModel):
    browser_actions: Optional[DataBrowserActions] = None
    """The render flow browser actions status results."""

    cookies: Optional[List[object]] = None
    """The cookies collected from browser actions during the task."""

    eval: Optional[List[object]] = None
    """The evaluation results from browser actions during the task."""

    fetch: Optional[List[object]] = None
    """The http requests from browser actions made during the task."""

    headers: Optional[Dict[str, str]] = None
    """The headers received during the task."""

    html: Optional[str] = None
    """The HTML content of the page."""

    markdown: Optional[str] = None
    """The Markdown version of the HTML content."""

    network_capture: Optional[List[DataNetworkCapture]] = None
    """The network capture data collected during the task."""

    parsing: Optional[DataParsing] = None
    """The parsing results extracted from the HTML & network content."""

    redirects: Optional[List[DataRedirect]] = None
    """The list of redirects that occurred during the task."""

    screenshots: Optional[List[object]] = None
    """The screenshots from browser actions taken during the task."""


class Metadata(BaseModel):
    driver: Optional[str] = None
    """The driver used for the task."""

    localization_id: Optional[str] = None
    """The localization identifier for the query."""

    query_duration: Optional[float] = None
    """The duration in milliseconds of the query processing."""

    query_time: Optional[str] = None
    """The time when the query was received."""

    response_parameters: Optional[object] = None
    """Additional response parameters."""

    tag: Optional[str] = None
    """A tag associated with the query."""

    template_id: Optional[str] = None
    """The identifier of the template used for the query."""


class Debug(BaseModel):
    performance_metrics: Optional[Dict[str, float]] = None
    """Performance metrics collected during the task."""

    proxy_total_bytes_usage: Optional[float] = None
    """Total bytes used by the proxy during the task."""

    transformed_output: Optional[object] = None
    """The transformed output after applying any transformations."""

    userbrowser: Optional[object] = None
    """The userbrowser instance using during the task."""


class PaginationNextPageParams(BaseModel):
    next_page_params: Dict[str, object]


class PaginationUnionMember1(BaseModel):
    next_page_params: Dict[str, object]


Pagination: TypeAlias = Union[PaginationNextPageParams, List[PaginationUnionMember1]]


class AgentGetResponse(BaseModel):
    data: Data

    metadata: Metadata

    status: Literal["success", "skipped", "fatal", "error", "postponed", "ignored", "rejected", "blocked"]
    """The status of the task."""

    task_id: str
    """Unique identifier for the task."""

    url: str
    """The final URL."""

    debug: Optional[Debug] = None

    pagination: Optional[Pagination] = None
    """Pagination information if applicable."""

    status_code: Optional[float] = None
    """The HTTP status code of the task."""

    warnings: Optional[List[str]] = None
    """List of warnings generated during the task."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import overload

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import required_args, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ...types.v2 import agent_get_params, agent_async_params
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.v2.agent_get_response import AgentGetResponse
from ...types.v2.agent_async_response import AgentAsyncResponse

__all__ = ["AgentResource", "AsyncAgentResource"]


class AgentResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AgentResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Nimbleway/webit-client-python#accessing-raw-response-data-eg-headers
        """
        return AgentResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AgentResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Nimbleway/webit-client-python#with_streaming_response
        """
        return AgentResourceWithStreamingResponse(self)

    @overload
    def async_(
        self,
        *,
        params: Dict[str, object],
        template: str,
        localization: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentAsyncResponse:
        """
        Execute WSA Realtime Endpoint

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def async_(
        self,
        *,
        agent: str,
        params: Dict[str, object],
        localization: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentAsyncResponse:
        """
        Execute WSA Realtime Endpoint

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["params", "template"], ["agent", "params"])
    def async_(
        self,
        *,
        params: Dict[str, object],
        template: str | Omit = omit,
        localization: bool | Omit = omit,
        agent: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentAsyncResponse:
        return self._post(
            "/agent/async",
            body=maybe_transform(
                {
                    "params": params,
                    "template": template,
                    "localization": localization,
                    "agent": agent,
                },
                agent_async_params.AgentAsyncParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AgentAsyncResponse,
        )

    @overload
    def get(
        self,
        *,
        params: Dict[str, object],
        template: str,
        localization: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentGetResponse:
        """
        Execute WSA Realtime Endpoint

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def get(
        self,
        *,
        agent: str,
        params: Dict[str, object],
        localization: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentGetResponse:
        """
        Execute WSA Realtime Endpoint

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["params", "template"], ["agent", "params"])
    def get(
        self,
        *,
        params: Dict[str, object],
        template: str | Omit = omit,
        localization: bool | Omit = omit,
        agent: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentGetResponse:
        return self._post(
            "/agent",
            body=maybe_transform(
                {
                    "params": params,
                    "template": template,
                    "localization": localization,
                    "agent": agent,
                },
                agent_get_params.AgentGetParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AgentGetResponse,
        )


class AsyncAgentResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAgentResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Nimbleway/webit-client-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAgentResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAgentResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Nimbleway/webit-client-python#with_streaming_response
        """
        return AsyncAgentResourceWithStreamingResponse(self)

    @overload
    async def async_(
        self,
        *,
        params: Dict[str, object],
        template: str,
        localization: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentAsyncResponse:
        """
        Execute WSA Realtime Endpoint

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def async_(
        self,
        *,
        agent: str,
        params: Dict[str, object],
        localization: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentAsyncResponse:
        """
        Execute WSA Realtime Endpoint

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["params", "template"], ["agent", "params"])
    async def async_(
        self,
        *,
        params: Dict[str, object],
        template: str | Omit = omit,
        localization: bool | Omit = omit,
        agent: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentAsyncResponse:
        return await self._post(
            "/agent/async",
            body=await async_maybe_transform(
                {
                    "params": params,
                    "template": template,
                    "localization": localization,
                    "agent": agent,
                },
                agent_async_params.AgentAsyncParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AgentAsyncResponse,
        )

    @overload
    async def get(
        self,
        *,
        params: Dict[str, object],
        template: str,
        localization: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentGetResponse:
        """
        Execute WSA Realtime Endpoint

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def get(
        self,
        *,
        agent: str,
        params: Dict[str, object],
        localization: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentGetResponse:
        """
        Execute WSA Realtime Endpoint

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["params", "template"], ["agent", "params"])
    async def get(
        self,
        *,
        params: Dict[str, object],
        template: str | Omit = omit,
        localization: bool | Omit = omit,
        agent: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentGetResponse:
        return await self._post(
            "/agent",
            body=await async_maybe_transform(
                {
                    "params": params,
                    "template": template,
                    "localization": localization,
                    "agent": agent,
                },
                agent_get_params.AgentGetParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AgentGetResponse,
        )


class AgentResourceWithRawResponse:
    def __init__(self, agent: AgentResource) -> None:
        self._agent = agent

        self.async_ = to_raw_response_wrapper(
            agent.async_,
        )
        self.get = to_raw_response_wrapper(
            agent.get,
        )


class AsyncAgentResourceWithRawResponse:
    def __init__(self, agent: AsyncAgentResource) -> None:
        self._agent = agent

        self.async_ = async_to_raw_response_wrapper(
            agent.async_,
        )
        self.get = async_to_raw_response_wrapper(
            agent.get,
        )


class AgentResourceWithStreamingResponse:
    def __init__(self, agent: AgentResource) -> None:
        self._agent = agent

        self.async_ = to_streamed_response_wrapper(
            agent.async_,
        )
        self.get = to_streamed_response_wrapper(
            agent.get,
        )


class AsyncAgentResourceWithStreamingResponse:
    def __init__(self, agent: AsyncAgentResource) -> None:
        self._agent = agent

        self.async_ = async_to_streamed_response_wrapper(
            agent.async_,
        )
        self.get = async_to_streamed_response_wrapper(
            agent.get,
        )
